==> kubernetes-junit-3.1.1-sources.jar: io/dekorate/testing/config/KubernetesIntegrationTestConfigBuilder.java <==
package io.dekorate.testing.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;

 /**
  * Generated
  */
public class KubernetesIntegrationTestConfigBuilder extends KubernetesIntegrationTestConfigFluentImpl<KubernetesIntegrationTestConfigBuilder> implements VisitableBuilder<KubernetesIntegrationTestConfig,KubernetesIntegrationTestConfigBuilder>{
  public KubernetesIntegrationTestConfigBuilder() {
    this(false);
  }
  public KubernetesIntegrationTestConfigBuilder(Boolean validationEnabled) {
    this(new KubernetesIntegrationTestConfig(), validationEnabled);
  }
  public KubernetesIntegrationTestConfigBuilder(KubernetesIntegrationTestConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public KubernetesIntegrationTestConfigBuilder(KubernetesIntegrationTestConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new KubernetesIntegrationTestConfig(), validationEnabled);
  }
  public KubernetesIntegrationTestConfigBuilder(KubernetesIntegrationTestConfigFluent<?> fluent,KubernetesIntegrationTestConfig instance) {
    this(fluent, instance, false);
  }
  public KubernetesIntegrationTestConfigBuilder(KubernetesIntegrationTestConfigFluent<?> fluent,KubernetesIntegrationTestConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDeployEnabled(instance.isDeployEnabled()); 
    fluent.withBuildEnabled(instance.isBuildEnabled()); 
    fluent.withReadinessTimeout(instance.getReadinessTimeout()); 
    fluent.withAdditionalModules(instance.getAdditionalModules()); 
    this.validationEnabled = validationEnabled; 
  }
  public KubernetesIntegrationTestConfigBuilder(KubernetesIntegrationTestConfig instance) {
    this(instance,false);
  }
  public KubernetesIntegrationTestConfigBuilder(KubernetesIntegrationTestConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withDeployEnabled(instance.isDeployEnabled()); 
    this.withBuildEnabled(instance.isBuildEnabled()); 
    this.withReadinessTimeout(instance.getReadinessTimeout()); 
    this.withAdditionalModules(instance.getAdditionalModules()); 
    this.validationEnabled = validationEnabled; 
  }
  KubernetesIntegrationTestConfigFluent<?> fluent;
  Boolean validationEnabled;
  public EditableKubernetesIntegrationTestConfig build() {
    EditableKubernetesIntegrationTestConfig buildable = new EditableKubernetesIntegrationTestConfig(fluent.isDeployEnabled(),fluent.isBuildEnabled(),fluent.getReadinessTimeout(),fluent.getAdditionalModules());
    return buildable;
  }
  
}

==> kubernetes-junit-4.0.0-sources.jar: io/dekorate/testing/config/KubernetesIntegrationTestConfigBuilder.java <==
package io.dekorate.testing.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;

 /**
  * Generated
  */
public class KubernetesIntegrationTestConfigBuilder extends KubernetesIntegrationTestConfigFluent<KubernetesIntegrationTestConfigBuilder> implements VisitableBuilder<KubernetesIntegrationTestConfig,KubernetesIntegrationTestConfigBuilder>{
  public KubernetesIntegrationTestConfigBuilder() {
    this(false);
  }
  public KubernetesIntegrationTestConfigBuilder(Boolean validationEnabled) {
    this(new KubernetesIntegrationTestConfig(), validationEnabled);
  }
  public KubernetesIntegrationTestConfigBuilder(KubernetesIntegrationTestConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public KubernetesIntegrationTestConfigBuilder(KubernetesIntegrationTestConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new KubernetesIntegrationTestConfig(), validationEnabled);
  }
  public KubernetesIntegrationTestConfigBuilder(KubernetesIntegrationTestConfigFluent<?> fluent,KubernetesIntegrationTestConfig instance) {
    this(fluent, instance, false);
  }
  public KubernetesIntegrationTestConfigBuilder(KubernetesIntegrationTestConfigFluent<?> fluent,KubernetesIntegrationTestConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new KubernetesIntegrationTestConfig());

    if (instance != null) {
      fluent.withDeployEnabled(instance.isDeployEnabled());
      fluent.withBuildEnabled(instance.isBuildEnabled());
      fluent.withReadinessTimeout(instance.getReadinessTimeout());
      fluent.withAdditionalModules(instance.getAdditionalModules());
    }
    this.validationEnabled = validationEnabled; 
  }
  public KubernetesIntegrationTestConfigBuilder(KubernetesIntegrationTestConfig instance) {
    this(instance,false);
  }
  public KubernetesIntegrationTestConfigBuilder(KubernetesIntegrationTestConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new KubernetesIntegrationTestConfig());

    if (instance != null) {
      this.withDeployEnabled(instance.isDeployEnabled());
      this.withBuildEnabled(instance.isBuildEnabled());
      this.withReadinessTimeout(instance.getReadinessTimeout());
      this.withAdditionalModules(instance.getAdditionalModules());
    }
    this.validationEnabled = validationEnabled; 
  }
  KubernetesIntegrationTestConfigFluent<?> fluent;
  Boolean validationEnabled;
  public EditableKubernetesIntegrationTestConfig build() {
    EditableKubernetesIntegrationTestConfig buildable = new EditableKubernetesIntegrationTestConfig(fluent.isDeployEnabled(),fluent.isBuildEnabled(),fluent.getReadinessTimeout(),fluent.getAdditionalModules());
    return buildable;
  }
  
}
